@@ -12,19 +12,19 @@ import (
 
 func (e *Engine) killCmd(cmd *exec.Cmd) (pid int, err error) {
 	pid = cmd.Process.Pid
+	pgid, err := syscall.Getpgid(cmd.Process.Pid)
+	if err != nil {
+		return pgid, errors.Wrapf(err, "failed to get pgid, pid %v", pid)
+	}
 
 	if e.config.Build.SendInterrupt {
 		// Sending a signal to make it clear to the process that it is time to turn off
-		if err = syscall.Kill(pid, syscall.SIGINT); err != nil {
+		if err = syscall.Kill(-pgid, syscall.SIGINT); err != nil {
 			e.mainDebug("trying to send signal failed %v", err)
 			return
 		}
 		time.Sleep(e.config.Build.KillDelay * time.Millisecond)
 	}
-	pgid, err := syscall.Getpgid(cmd.Process.Pid)
-	if err != nil {
-		return pgid, errors.Wrapf(err, "failed to get pgid, pid %v", pid)
-	}
 	err = syscall.Kill(-pgid, syscall.SIGKILL)
 	if err != nil {
 		return pid, errors.Wrapf(err, "failed to kill process by pgid %v", pgid)
